==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxValueChangedEventArgsDescription } from "./MultiColumnComboBoxValueChangedEventArgsDescription";
/**
 * @hidden
 */
var MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, _super);
    function MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a == null) {
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.d = function (a) {
        MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b(a);
        a.ac("MultiColumnComboBoxValueChangedEventArgs", function () { return new MultiColumnComboBoxValueChangedEventArgsDescription(); });
        a.ab("MultiColumnComboBoxValueChangedEventArgs", MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.$t = markType(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata;
}(Base));
export { MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxValueChangedEventArgsDescription } from "./MultiColumnComboBoxValueChangedEventArgsDescription";
/**
 * @hidden
 */
var MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, _super);
    function MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a == null) {
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.d = function (a) {
        MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b(a);
        a.ae("MultiColumnComboBoxValueChangedEventArgs", function () { return new MultiColumnComboBoxValueChangedEventArgsDescription(); });
        a.ad("MultiColumnComboBoxValueChangedEventArgs", MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.$t = markType(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata;
}(Base));
export { MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata };
